#!/usr/bin/env bash
#
# Check that the currently checked out git commit is suitable for publishing to
# npm.
#
# This is run before npm publish via the prepublishOnly lifecycle hook in
# package.json.
#

set -euo pipefail
package_name=$(npm info ./ name)
package_version=$(npm info ./ version)
commit_tag=$(
  { git describe --exact-match --match='v*' 2>/dev/null || true; } \
  | sed -e s/^v//
)

if [[ ! $commit_tag ]]; then
  echo "Error: cannot publish, the checked out git commit is not tagged with " \
    "a v* tag" >&2
  exit 1
fi

if [[ ${commit_tag:?} != "${package_version:?}" ]]; then
  echo "Error: cannot publish, the commit tag ${commit_tag@Q} does not match" \
    "the package.json version: ${package_version@Q}" >&2
  exit 2
fi
