#!/usr/bin/env bash
#
# Exit 0 if the current repo's NPM package is available from the package registry
#

set -euo pipefail

function get_published_version() {
  status=0
  npm_info_output=$(npm info "${package_name:?}" version 2>&1) || status=$?
  if [[ $npm_info_output =~ ^"npm error code E404"$'\n' ]]; then
    echo "unpublished"
    return
  elif [[ $status != 0 ]]; then
    echo "${npm_info_output:?}" >&2
    return "${status:?}"
  fi
  echo "${npm_info_output:?}"
}

package_name=$(npm info ./ name)
package_version=$(npm info ./ version)
published_version=$(get_published_version)

if [[ ${package_version:?} == ${published_version:?} ]]; then
  echo "Package ${package_name:?}@${package_version:?} is already published" >&2
  exit 0
fi
echo "Package ${package_name:?}@${package_version:?} has not been published" >&2
exit 1
